@@ -19,8 +19,9 @@ tSIR <-
     rotat <- tSIRRotate(x, y, h, ...)
     x <- rotat$x
     
-    W <- list()
-    for(i in 1:length(stand$S)){
+    r <- length(stand$S)
+    W <- vector("list", r)
+    for(i in 1:r){
       W[[i]] <- rotat$U[[i]]%*%stand$S[[i]]
     }
     
